Index: trunk/psModules/src/detrend/pmFringeStats.h
===================================================================
--- trunk/psModules/src/detrend/pmFringeStats.h	(revision 21183)
+++ trunk/psModules/src/detrend/pmFringeStats.h	(revision 24836)
@@ -142,11 +142,27 @@
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-/// Write an array of fringes measurements to a FITS table.
-///
-/// Writes an array of fringe measurements for a cell as a FITS table in the analysis metadata.  The array of
-/// fringe statistics must all use the same fringe regions (or there is no point in storing them all
-/// together).  The header is supplemented with scalar values dX, dY, nX and nY (as PSFRNGDX, PSFRNGDY,
-/// PSFRNGNX, PSFRNGNY) from the fringe regions, while the fringe coordinates and mask are written as a FITS
-/// table (as x, y, mask, f, df; f and df are vectors).
+/// Convert an array of fringes measurements to a psArray suitable for writing as a FITS table.
+///
+/// Converts an array of fringe measurements for a cell into the corresponding rows of a FITS
+/// table (array of psMetadata).  The array of fringe statistics must all use the same fringe
+/// regions (or there is no point in storing them all together).  The header is supplemented
+/// with scalar values dX, dY, nX and nY (as PSFRNGDX, PSFRNGDY, PSFRNGNX, PSFRNGNY) from the
+/// fringe regions, while the fringe coordinates and mask are written as a FITS table rows (as
+/// x, y, mask, f, df; f and df are vectors).  Use psFitsTableWrite to save the resulting rows
+/// to disk.
+psArray *pmFringesFormatTable(psMetadata *header, const psArray *fringes);
+
+
+/// Parses an array of fringes measurements from a FITS table.
+///
+/// The fringes for the cell are read from the FITS table (array of psMetadata rows).  The
+/// table provides the region and the (possibly multiple) fringe statistics for that region.
+/// The supplied header defines the scalar values dX, dY, nX and nY (as PSFRNGDX, PSFRNGDY,
+/// PSFRNGNX, PSFRNGNY)
+psArray *pmFringesParseTable(psArray *table, psMetadata *header);
+
+/// Deprecated Function: converts the fringes to a FITS table (array of psMetadata) and saves
+/// them on the cell->analysis; scalar values are dX, dY, nX and nY are written to the header
+/// (as PSFRNGDX, PSFRNGDY, PSFRNGNX, PSFRNGNY)
 bool pmFringesFormat(pmCell *cell,   ///< Cell for which to write
                      psMetadata *header, ///< Header, or NULL
@@ -154,12 +170,8 @@
                     );
 
 /// Parses an array of fringes measurements from a FITS table.
 ///
 /// The fringes for the cell are read from the FITS table in the analysis metadata.  The table provides the
 /// region and the (possibly multiple) fringe statistics for that region.  The current extension is used if
 /// the extension name is not provided.
 psArray *pmFringesParse(pmCell *cell ///< Cell for which to read fringes
                        );
-
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -154,12 +170,8 @@
                     );
 
-/// Parses an array of fringes measurements from a FITS table.
-///
-/// The fringes for the cell are read from the FITS table in the analysis metadata.  The table provides the
-/// region and the (possibly multiple) fringe statistics for that region.  The current extension is used if
-/// the extension name is not provided.
+/// Deprecated Function: pulls a the header and FITS table (array of psMetadata) representing
+/// the fringes from the cell->analysis and converts to fringe measurements
 psArray *pmFringesParse(pmCell *cell ///< Cell for which to read fringes
                        );
